Exception: Fopost::ConfigurationError
- Inherits:
-
StandardError
- Object
- StandardError
- Fopost::ConfigurationError
- Defined in:
- lib/fopost/errors.rb
Overview
Raised before a request goes out, when the client is misconfigured.
Raised before a request goes out, when the client is misconfigured.